<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>LayerCompatibility</name>
    <message>
        <location filename="../LayerCompatibility.js" line="+30"/>
        <source>Layer</source>
        <translation>Vrstva</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Compatibility</source>
        <translation>Kompatibilita</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Layer 0</source>
        <translation>Vrstva 0</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer 0 behaves like a regular layer (QCAD)</source>
        <translation>Vrstva 0 sa správa ako normálna vrstva (QCad)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Layer 0 behaves differently (best compatibility)</source>
        <translation>Vrstva 0 sa správa odlišne (najlepšia kompatibilita)</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
        <translation>Prvky v bloku na vrstve 0 prevezmú vlastnosti a viditeľnosť bloku.</translation>
    </message>
    <message>
        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
        <translation type="vanished">Prvky v blokoch na vrstve 0 vziať na parametre referencie bloku (kompatibilita)</translation>
    </message>
</context>
</TS>
